==> huggingface_hub-0.27.1.gh.tar.gz: huggingface_hub-0.27.1/docs/source/hi/index.md <==
<!--⚠️ Note that this file is in Markdown but contains specific syntax for our doc-builder (similar to MDX) that may not be
rendered properly in your Markdown viewer.
-->

# 🤗 हब क्लाइंट लाइब्रेरी

`huggingface_hub` लाइब्रेरी आपको [हगिंग फेस' के साथ काम करने की अनुमति देती है
हब](https://hf.co), रचनाकारों और सहयोगियों के लिए एक मशीन लर्निंग प्लेटफॉर्म।
अपनी परियोजनाओं के लिए पूर्व-प्रशिक्षित मॉडल और डेटासेट खोजें या सैकड़ों के साथ खेलें
हब पर होस्ट किए गए मशीन लर्निंग ऐप्स। आप अपने स्वयं के मॉडल भी बना और साझा कर सकते हैं
और समुदाय के साथ डेटासेट। `huggingface_hub` लाइब्रेरी इसका एक आसान तरीका प्रदान करती है
ये सभी चीजें Python के साथ करें।

इसके साथ काम के लिए [quick-start] (क्विक-स्टार्ट) पढ़ें
`huggingface_hub` लाइब्रेरी। आप सीखेंगे कि हब से फ़ाइलें कैसे डाउनलोड करें, कैसे बनाएं
रिपॉजिटरी, और हब पर फ़ाइलें अपलोड करें। प्रबंधन करने के तरीके के बारे में अधिक जानने के लिए पढ़ते रहें
🤗 हब पर आपके भंडार, चर्चाओं में कैसे बातचीत करें या यहां तक ​​​​कि कैसे पहुंचें
अनुमान एपीआई.

<div class="mt-10">
  <div class="w-full flex flex-col space-y-4 md:space-y-0 md:grid md:grid-cols-2 md:gap-y-4 md:gap-x-5">

    <a class="!no-underline border dark:border-gray-700 p-5 rounded-lg shadow hover:shadow-lg" href="./guides/overview">
      <div class="w-full text-center bg-gradient-to-br from-indigo-400 to-indigo-500 rounded-lg py-1.5 font-semibold mb-5 text-white text-lg leading-relaxed">How-to guides</div>
      <p class="text-gray-700">Practical guides to help you achieve a specific goal. Take a look at these guides to learn how to use huggingface_hub to solve real-world problems.</p>
    </a>

    <a class="!no-underline border dark:border-gray-700 p-5 rounded-lg shadow hover:shadow-lg" href="./package_reference/overview">
      <div class="w-full text-center bg-gradient-to-br from-purple-400 to-purple-500 rounded-lg py-1.5 font-semibold mb-5 text-white text-lg leading-relaxed">Reference</div>
      <p class="text-gray-700">Exhaustive and technical description of huggingface_hub classes and methods.</p>
    </a>

    <a class="!no-underline border dark:border-gray-700 p-5 rounded-lg shadow hover:shadow-lg" href="./concepts/git_vs_http">
      <div class="w-full text-center bg-gradient-to-br from-pink-400 to-pink-500 rounded-lg py-1.5 font-semibold mb-5 text-white text-lg leading-relaxed">Conceptual guides</div>
      <p class="text-gray-700">High-level explanations for building a better understanding of huggingface_hub philosophy.</p>
    </a>

  </div>
</div>

<!--
<a class="!no-underline border dark:border-gray-700 p-5 rounded-lg shadow hover:shadow-lg" href="./tutorials/overview"
  ><div class="w-full text-center bg-gradient-to-br from-blue-400 to-blue-500 rounded-lg py-1.5 font-semibold mb-5 text-white text-lg leading-relaxed">Tutorials</div>
  <p class="text-gray-700">Learn the basics and become familiar with using huggingface_hub to programmatically interact with the 🤗 Hub!</p>
</a> -->

## योगदान देना

`huggingface_hub` में सभी योगदानों का स्वागत किया जाता है और समान रूप से महत्व दिया जाता है! 🤗 इसके अलावा
कोड में मौजूदा समस्याओं को जोड़ने या ठीक करने से आप इसे बेहतर बनाने में भी मदद कर सकते हैं
यह सुनिश्चित करके कि दस्तावेज़ीकरण सटीक और अद्यतित है, प्रश्नों के उत्तर देने में सहायता करें
मुद्दे, और नई सुविधाओं का अनुरोध करें जो आपको लगता है कि लाइब्रेरी में सुधार करेगी। पर एक नज़र डालें
[योगदान
गाइड](https://github.com/huggingface/huggingface_hub/blob/main/CONTRIBUTING.md)
नया मुद्दा या सुविधा अनुरोध कैसे सबमिट करें, पुल अनुरोध कैसे सबमिट करें, इसके बारे में और जानें, और यह सुनिश्चित करने के लिए कि सब कुछ अपेक्षा के अनुरूप काम करता है, अपने योगदान का परीक्षण कैसे करें।

योगदानकर्ताओं को भी हमारे [कोड का] सम्मान करना चाहिए
आचरण(https://github.com/huggingface/huggingface_hub/blob/main/CODE_OF_CONDUCT.md) से
सभी के लिए एक समावेशी और स्वागतयोग्य सहयोगी स्थान बनाएं।

==> huggingface_hub-0.30.2.gh.tar.gz: huggingface_hub-0.30.2/docs/source/hi/index.md <==
<!--⚠️ Note that this file is in Markdown but contains specific syntax for our doc-builder (similar to MDX) that may not be
rendered properly in your Markdown viewer.
-->

# 🤗 हब क्लाइंट लाइब्रेरी

`huggingface_hub` लाइब्रेरी आपको [हगिंग फेस' के साथ काम करने की अनुमति देती है
हब](https://hf.co), रचनाकारों और सहयोगियों के लिए एक मशीन लर्निंग प्लेटफॉर्म।
अपनी परियोजनाओं के लिए पूर्व-प्रशिक्षित मॉडल और डेटासेट खोजें या सैकड़ों के साथ खेलें
हब पर होस्ट किए गए मशीन लर्निंग ऐप्स। आप अपने स्वयं के मॉडल और डेटासेट्स भी बना सकते हैं
और उन्हें समुदाय के साथ साझा कर सकते हैं। `huggingface_hub` लाइब्रेरी इसका एक आसान तरीका प्रदान करती है
ये सभी चीजें Python के साथ करें।

इसके साथ काम के लिए [quick-start] (क्विक-स्टार्ट) पढ़ें
`huggingface_hub` लाइब्रेरी। आप सीखेंगे कि हब से फाइलें कैसे डाउनलोड करें, एक रिपॉजिटरी कैसे बनाएं,
और हब पर फाइलें कैसे अपलोड करें। 🤗 हब पर अपनी रिपॉजिटरी कैसे प्रबंधित करें, चर्चाओं में कैसे भाग लें,
या इन्फरेंस एपीआई तक कैसे पहुँचें, इसके बारे में अधिक जानने के लिए पढ़ते रहें।

<div class="mt-10">
  <div class="w-full flex flex-col space-y-4 md:space-y-0 md:grid md:grid-cols-2 md:gap-y-4 md:gap-x-5">

    <a class="!no-underline border dark:border-gray-700 p-5 rounded-lg shadow hover:shadow-lg" href="./guides/overview">
      <div class="w-full text-center bg-gradient-to-br from-indigo-400 to-indigo-500 rounded-lg py-1.5 font-semibold mb-5 text-white text-lg leading-relaxed">How-to guides</div>
      <p class="text-gray-700">Practical guides to help you achieve a specific goal. Take a look at these guides to learn how to use huggingface_hub to solve real-world problems.</p>
    </a>

    <a class="!no-underline border dark:border-gray-700 p-5 rounded-lg shadow hover:shadow-lg" href="./package_reference/overview">
      <div class="w-full text-center bg-gradient-to-br from-purple-400 to-purple-500 rounded-lg py-1.5 font-semibold mb-5 text-white text-lg leading-relaxed">Reference</div>
      <p class="text-gray-700">Exhaustive and technical description of huggingface_hub classes and methods.</p>
    </a>

    <a class="!no-underline border dark:border-gray-700 p-5 rounded-lg shadow hover:shadow-lg" href="./concepts/git_vs_http">
      <div class="w-full text-center bg-gradient-to-br from-pink-400 to-pink-500 rounded-lg py-1.5 font-semibold mb-5 text-white text-lg leading-relaxed">Conceptual guides</div>
      <p class="text-gray-700">High-level explanations for building a better understanding of huggingface_hub philosophy.</p>
    </a>

  </div>
</div>

<!--
<a class="!no-underline border dark:border-gray-700 p-5 rounded-lg shadow hover:shadow-lg" href="./tutorials/overview"
  ><div class="w-full text-center bg-gradient-to-br from-blue-400 to-blue-500 rounded-lg py-1.5 font-semibold mb-5 text-white text-lg leading-relaxed">Tutorials</div>
  <p class="text-gray-700">Learn the basics and become familiar with using huggingface_hub to programmatically interact with the 🤗 Hub!</p>
</a> -->

## योगदान देना

`huggingface_hub` में सभी योगदानों का स्वागत किया जाता है और समान रूप से महत्व दिया जाता है! 🤗 इसके अलावा
कोड में मौजूदा समस्याओं को जोड़ने या ठीक करने से आप इसे बेहतर बनाने में भी मदद कर सकते हैं
यह सुनिश्चित करके कि दस्तावेज़ीकरण सटीक और अद्यतित है, प्रश्नों के उत्तर देने में सहायता करें
मुद्दे, और नई सुविधाओं का अनुरोध करें जो आपको लगता है कि लाइब्रेरी में सुधार करेगी।
एक नया मुद्दा या सुविधा अनुरोध कैसे सबमिट करें, पुल अनुरोध कैसे सबमिट करें, और यह सुनिश्चित करने के लिए अपने योगदानों का परीक्षण कैसे करें कि सब कुछ अपेक्षा के अनुरूप काम करता है, इसके बारे में अधिक जानने के लिए [योगदान गाइड](https://github.com/huggingface/huggingface_hub/blob/main/CONTRIBUTING.md) पर एक नज़र डालें।

योगदानकर्ताओं को सभी के लिए एक समावेशी और स्वागत योग्य सहयोगी स्थान बनाने के लिए हमारे
[आचार संहिता](https://github.com/huggingface/huggingface_hub/blob/main/CODE_OF_CONDUCT.md), का भी सम्मान करना चाहिए।
